<?php
if (get_cookie('prd_inq') != 557528 && $app_setting->prd_first_pop_up == 1):
?>
    <div id="mydiv"></div>
    <!-- MultiStep Form -->
    <div class="container-fluid d-lg-none" id="grad1" style="position:fixed;z-index:999999;top: 15%;">
        <div class="row justify-content-center mt-0">
            <div class="col-11 col-sm-9 col-md-7 col-lg-6 text-center p-0 mb-2">
                <div class="card px-0 pb-0 mb-3">
                    <div class="row">
                        <div class="modal-close-2" onclick="close_adv_modal_2()">
                            <i class="fa fa-times modal-close-icon-2"></i>
                        </div>
                        <div class="col-md-12 mx-0">
                            <?php echo form_open(base_url() . 'home/add_prd_wlcome_form_inq_data', ['id' => 'msform']); ?>
                            <!-- progressbar -->
                            <fieldset>
                                <div class="background_bg h-100" style="background-image: url('');">
                                    <img loading="lazy" style="height:100%;" src="<?php echo base_url() ?><?php echo $product->prd_adv_pop_img ?>">
                                </div>
                                <input type="button" name="next" class="btn next action-button" value="Next Step" />
                            </fieldset>
                            <fieldset style="margin-top: 20px;padding-bottom: 20px;">
                                <div class="form-card">
                                    <h3 class="text-center">CONGRATS, YOU'RE IN!</h3>
                                    <p class="text-center">Complete Your Registration To View Product Details</p>
                                    <input type="text" name="inq_name" placeholder="Enter Your Name *" required />
                                    <input type="email" name="inq_email" placeholder="Enter Your Email ID *" required />
                                    <input type="number" name="inq_mob" placeholder="Enter Your Mobile No *" />
                                    <input type="hidden" name="inq_prd_id" value="<?php echo $product->prd_id ?>">
                                    <div class="form-group pb-3">
                                        <div class="g-recaptcha" data-sitekey="<?php echo $app_setting->captcha_site_key; ?>"></div>
                                    </div>
                                </div>
                                <input type="button" name="previous" class="btn btn-secondary previous action-button-previous" value="Previous" />
                                <button type="submit" name="make_payment" class="btn action-button">View Website</button>
                            </fieldset>
                            <?php echo form_close(); ?>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <div class="form" id="dekstop-adv-popup">
        <div class="container">
            <div class="row">
                <div class="col-sm-6 ">
                    <div class="form-data">
                        <h3 class="text-center">CONGRATS, YOU'RE IN!</h3>
                        <p class="text-center">Complete Your Registration To View Product Details</p>
                        <?php echo form_open(base_url() . 'home/add_prd_wlcome_form_inq_data'); ?>
                        <div class="form-group pb-3">
                            <input type="text" class="form-control new-filed f-name" placeholder="Enter Your Name *" name="inq_name" required>
                        </div>
                        <div class="form-group pb-3">
                            <input type="email" class="form-control new-filed f-email" placeholder="Enter Your Email ID *" name="inq_email" required>
                        </div>
                        <div class="form-group pb-3">
                            <input type="number" class="form-control new-filed f-phone" placeholder="Enter Your Mobile No *" name="inq_mob" required>
                            <input type="hidden" name="inq_prd_id" value="<?php echo $product->prd_id ?>">
                        </div>
                        <div class="form-group pb-3">
                            <div class="g-recaptcha" data-sitekey="<?php echo $app_setting->captcha_site_key; ?>"></div>
                        </div>
                        <div class="form-group">
                            <button class="btn btn-success prd_submit" type="submit">View Website Now</button>
                        </div>
                        <div class="form-group">
                            <span class="text-center">* we will not spam, rent, or sell your information... *</span>
                        </div>
                        <?php echo form_close(); ?>
                    </div>
                </div>
                <div class="col-sm-6 sst00" style="padding-right: 0">
                    <div class="modal-close" onclick="close_adv_modal()">
                        <i class="fa fa-times modal-close-icon" style="padding:5px"></i>
                    </div>
                    <div class="background_bg h-100" style="background-image: url('');">
                        <img loading="lazy" style="height:100%;" src="<?php echo base_url() ?><?php echo $product->prd_adv_pop_img ?>">
                    </div>
                </div>
            </div>
        </div>
    </div>
<?php endif; ?>

<div class="modal show" id="open_video_brochur" tabindex="-1" role="dialog" aria-labelledby="exampleModalLabel" aria-hidden="true">
    <div class="modal-dialog" role="document">
        <div class="modal-content">
            <div class="modal-header" style="border-bottom: none;padding-bottom: 0!important;">
                <button type="button" class="close" onclick="close_video_model()" data-dismiss="modal" aria-label="Close">
                    <span aria-hidden="true">&times;</span>
                </button>
            </div>
            <div class="modal-body" style="padding-top: 0!important;">
                <div style="padding:25px;padding-top: 0!important;">
                    <form>
                        <h6 class="text-center" style="font-weight: 500;">CONGRATS, YOU'RE IN!</h6>
                        <h5 class="text-center">Complete Your Registration To View Video Demo</h5>
                        <div class="row" style="padding-top:20px">
                            <div class="col-sm-6">
                                <div class="form-group">
                                    <input type="text" class="form-control" name="b_f_name" required="" placeholder="Enter First Name *" id="b_f_name">
                                </div>
                            </div>
                            <div class="col-sm-6">
                                <div class="form-group">
                                    <input type="text" class="form-control" name="b_l_name" required="" placeholder="Enter Last Name *" id="b_l_name">
                                </div>
                            </div>
                            <div class="col-sm-12">
                                <div class="form-group">
                                    <input type="email" class="form-control" name="b_email" required="" placeholder="Enter Email ID *" id="b_email">
                                </div>
                            </div>
                            <div class="col-sm-12">
                                <div class="form-group">
                                    <input type="number" class="form-control" name="b_mobile" required="" placeholder="Enter Mobile No *" id="b_mobile">
                                </div>
                            </div>
                            <div class="col-sm-12">
                                <div class="form-group">
                                    <div class="g-recaptcha" data-sitekey="<?php echo $app_setting->captcha_site_key; ?>"></div>
                                </div>
                            </div>
                            <input name="b_prd_id" type="hidden" required="" value="<?php echo $product->prd_id ?>" id="b_prd_id">
                            <div class="col-sm-12">
                                <button onclick="video_form_submit()" type="button" class="block">Submit</button>
                            </div>
                        </div>
                </div>
            </div>
            </form>
        </div>
    </div>
</div>

<div class="modal show" id="open_model_brochur" tabindex="-1" role="dialog" aria-labelledby="exampleModalLabel" aria-hidden="true">
    <div class="modal-dialog" role="document">
        <div class="modal-content">
            <div class="modal-header" style="border-bottom: none;padding-bottom: 0!important;">
                <button type="button" class="close" onclick="close_brochur_model()" data-dismiss="modal" aria-label="Close">
                    <span aria-hidden="true">&times;</span>
                </button>
            </div>
            <div class="modal-body" style="padding-top: 0!important;">
                <div style="padding:25px;padding-top: 0!important;">
                    <form>
                        <h6 class="text-center" style="font-weight: 500;">CONGRATS, YOU'RE IN!</h6>
                        <h5 class="text-center">Complete Your Registration To Download Brochure</h5>
                        <div class="row" style="padding-top:20px">
                            <div class="col-sm-6">
                                <div class="form-group">
                                    <input type="text" class="form-control" name="b_f_name" required="" placeholder="Enter First Name *" id="b_f_name_1">
                                </div>
                            </div>
                            <div class="col-sm-6">
                                <div class="form-group">
                                    <input type="text" class="form-control" name="b_l_name" required="" placeholder="Enter Last Name *" id="b_l_name_1">
                                </div>
                            </div>
                            <div class="col-sm-12">
                                <div class="form-group">
                                    <input type="email" class="form-control" name="b_email" required="" placeholder="Enter Email ID *" id="b_email_1">
                                </div>
                            </div>
                            <div class="col-sm-12">
                                <div class="form-group">
                                    <input type="number" class="form-control" name="b_mobile" required="" placeholder="Enter Mobile No *" id="b_mobile_1">
                                </div>
                            </div>
                            <div class="col-sm-12">
                                <div class="form-group">
                                    <div class="g-recaptcha" data-sitekey="<?php echo $app_setting->captcha_site_key; ?>"></div>
                                </div>
                            </div>
                            <input name="b_prd_id" type="hidden" required="" value="<?php echo $product->prd_id ?>" id="b_prd_id_1">
                            <div class="col-sm-12">
                                <button onclick="brochure_form_submit()" type="button" class="block">Submit</button>
                            </div>
                        </div>
                </div>
            </div>
            </form>
        </div>
    </div>
</div>
<div class="modal show" id="open_model_demo" tabindex="-1" role="dialog" aria-labelledby="exampleModalLabel" aria-hidden="true">
    <div class="modal-dialog" role="document">
        <div class="modal-content">
            <div class="modal-header" style="border-bottom: none;padding-bottom: 0!important;">
                <button type="button" class="close" onclick="close_demo_model()" data-dismiss="modal" aria-label="Close">
                    <span aria-hidden="true">&times;</span>
                </button>
            </div>
            <div class="modal-body" style="padding-top: 0!important;">
                <div style="padding:25px;padding-top: 0!important;">
                    <?php echo form_open(base_url() . 'home/request_for_product_admin_demo'); ?>
                    <h6 class="text-center" style="font-weight: 500;">CONGRATS, YOU'RE IN!</h6>
                    <h5 class="text-center">Complete Your Registration To Get Admin Panel Demo</h5>
                    <div class="row" style="padding-top:20px">
                        <div class="col-sm-6">
                            <div class="form-group">
                                <input type="text" class="form-control" name="f_name" required="" placeholder="Enter First Name *">
                            </div>
                        </div>
                        <div class="col-sm-6">
                            <div class="form-group">
                                <input type="text" class="form-control" name="l_name" required="" placeholder="Enter Last Name *">
                            </div>
                        </div>
                        <div class="col-sm-12">
                            <div class="form-group">
                                <input type="email" class="form-control" name="prd_adm_email" required="" placeholder="Enter Email ID *">
                            </div>
                        </div>
                        <div class="col-sm-12">
                            <div class="form-group">
                                <input type="number" class="form-control" name="prd_adm_mobile" required="" placeholder="Enter Mobile No *">
                            </div>
                        </div>
                        <div class="col-sm-12">
                            <div class="form-group">
                                <div class="g-recaptcha" data-sitekey="<?php echo $app_setting->captcha_site_key; ?>"></div>
                            </div>
                        </div>
                        <input name="prd_adm_prd_id" type="hidden" required="" value="<?php echo $product->prd_id ?>">
                        <div class="col-sm-12">
                            <button type="submit" class="block">Submit</button>
                        </div>
                    </div>
                </div>
            </div>
            <?php echo form_close(); ?>
        </div>
    </div>
</div>